@@ -10,7 +10,11 @@ function package:registerCommands ()
     if type(cp) ~= "string" then SU.error("Bad argument to \\unicode") end
     local hlist = SILE.typesetter.state.nodes
     local char = SU.utf8charfromcodepoint(cp)
-    if #hlist > 1 and hlist[#hlist].is_unshaped then
+    if #hlist > 1 and hlist[#hlist].is_unshaped
+                  and pl.tablex.deepcompare(hlist[#hlist].options, SILE.font.loadDefaults({})) then
+      -- Stack character with a preceeding unshaped node if its font is the
+      -- same as the current one, so that combining characters (e.g. diacritics)
+      -- and kerning works with \unichar'ed code points too.
       hlist[#hlist].text = hlist[#hlist].text .. char
     else
       SILE.typesetter:typeset(char)
@@ -28,12 +32,11 @@ Some Unicode characters are hard to locate on a standard keyboard, and so are di
 The \autodoc:package{unichar} package helps with this problem by providing a command to enter Unicode codepoints.
 After loading \autodoc:package{unichar}, the \autodoc:command{\unichar} command becomes available:
 
-\begin{verbatim}
-\line
-% Note we are directly outputing the unicode to workaround https://github.com/sile-typesetter/sile/issues/991
-\\unichar\{U+263A\} \% produces \font[family=Symbola]{☺}
-\line
-\end{verbatim}
+\begin[type=autodoc:codeblock]{raw}
+\unichar{U+263A}
+\end{raw}
+
+This produces: \font[family=Symbola]{\unichar{U+263A}}
 
 If the argument to \autodoc:command{\unichar} begins \code{U+}, \code{u+}, \code{0x} or \code{0X}, then it is assumed to be a hexadecimal value.
 Otherwise it is assumed to be a decimal codepoint.
